@@ -17,6 +17,10 @@ def client(
 ) -> Tuple[Response, Any]:
     params = params if params is not None else {}
     headers = headers if headers is not None else {'API-Key': api_key}
+    headers |= {
+        'Cache-Control': 'no-store,no-cache,must-revalidate,max-age=0,post-check=0,pre-check=0',
+        'Pragma': 'no-cache',
+    }
     try:
         response = method(url, params=params, headers=headers, json=json_payload)
     except requests.exceptions.ConnectionError:
