@@ -3,12 +3,22 @@ from datetime import date, datetime
 from typing import Optional, List, Dict
 
 
+@dataclass
+class Response:
+    url: str
+    status_code: int
+    headers: Dict[str, str]
+    payload: Optional[str] = None
+    body: Optional[str] = None
+
+
 @dataclass
 class TestResult:
     title: str = ''
     status: int = 0
     message: Optional[str] = None
     duration: int = 0
+    response: Optional[Response] = None
 
     @property
     def status_text(self):
@@ -36,11 +46,8 @@ class Product:
     name: str
     use_timeslots: bool
     description: Optional[str]
-
-@dataclass
-class DailyAvailability:
-    date: date
-    max_tickets: int
+    is_refundable: bool
+    cutoff_time: int
 
 
 @dataclass
